<?php
	ob_start();

	// set this to go against the testing server...
	define('BOOMTIME_TESTING_SERVER', true);

	// Set query string of URL to ?phpinfo to see the php configuration info.
	if (isset($_GET['phpinfo']))
	{
		phpinfo();
		exit;
	}
?>
<html>
<head></head>
<body>
<h1>BoomTime Services API Test</h1>
<?php
	include("boomtime_services.php");

	$BT_Services = new BoomTime_Services('{affiliate_id}', '{api_password}');

	echo "<hr><p>";
	echo "BoomTime Services version ".$BT_Services->version()."<br>";
	echo "BoomTime Services API version ".$BT_Services->api_version();
	echo "</p><hr>";

	$uuid = BoomTime_Services::uuidgen();
	echo "<pre>\nTest BoomTime_Services::uuidgen() = {$uuid}\n</pre>";

	/**
	 * echo_params() just echoes the given params for the purpose of testing
	 * a full API request and response.
	 *
	 * request params: associative array
	 * response value: text
	 */
	$params = array
	(
		'one' => 1,
		'two' => 2,
		'three' => 3
	);
	if (!$result = $BT_Services->echo_params($params))
		$result = $BT_Services->last_fault();
	echo "<pre>{$result}</pre>";

	/**
	 * account_status() checks the status of a given account:
	 *
	 * request params: associative array
	 *   account_uuid = (string:32) the assigned uuid for an account.
	 *
	 * response values: associative array
	 *   status = 0 for signup uncompleted, 1 for signup completed.
	 *   boomtime_id = (string:16) the boomtime_id of the account if signup.
	 *     is complete or null if status is not 1.
	 *   account_id = (string:32) hosting account id.
	 *   account_property = (string:32) hosting account property.
	 *   account_domain = (string:70) the public domain account.
	 */
	$params = array
	(
		'account_uuid' => '133a2b01473b4e41aab539101397c06f'
	);
	if (!$result = $BT_Services->account_status($params))
		$result = $BT_Services->last_fault();
	else
		$result = 'account_status'.str_replace('Array', '', print_r($result, true));
	echo "<pre>{$result}</pre>";

	/**
	 * account_login() generates a login token and a URL for control panel login:
	 *
	 * request params: associative array
	 *   account_uuid = (string:32) the assigned uuid for an account.
	 *
	 * response values: associative array
	 *   token = one use login token (valid 90 seconds).
	 *   token_expires = token valid until this time UTC.
	 *   login_url = redirect to this URL to login.
	 *   hash = login security hash (generated locally)
	 */
	$params = array
	(
		'account_uuid' => '133a2b01473b4e41aab539101397c06f'
	);
	if (!$result = $BT_Services->account_login($params))
		$result = $BT_Services->last_fault();
	else
		$result = 'account_login'.str_replace('Array', '', print_r($result, true));
	echo "<pre>{$result}</pre>";

	/**
	 * account_signup() saves account information returns a redirect URL:
	 *
	 * request params: associative array (=? optional fields)
	 *   account_uuid = (string:32) the assigned uuid for an account.
	 *   account_domain = (string:70) the public domain account (no www).
	 *   account_id =? (string:32) hosting account id.
	 *   account_property =? (string:32) hosting account property.
	 *   email = (string:100) the assigned uuid for an account.
	 *   company = (string:50) either company for first/last name is required.
	 *   first_name = (string:30) either company for first/last name is required.
	 *   last_name = (string:30) either company for first/last name is required.
	 *   address_1 =? (string:40) first address line.
	 *   address_2 =? (string:40) second address line.
	 *   city =? (string:40) city.
	 *   state =? (string:20) state, province or region.
	 *   postal =? (string:20) postal or ZIP code.
	 *   country =? (string:50) country
	 *   phone_1 =? (string:30) first phone number.
	 *   phone_2 =? (string:30) second phone number.
	 *
	 * response values: associative array
	 *   action = 'new' if this is a new signup or 'update' if a previously
	 *     submitted but uncompleted signup was updated.
	 *   token = signup token (valid 30 years).
	 *   token_expires = token valid until this time UTC.
	 *   signup_url = redirect to this URL to login.
	 *   hash = login security hash (generated locally)
	 */
	$params = array
	(
		'account_uuid' => 'b27e3d839a4242e2829d0c189ee41533',
		'account_domain' => 'newaccount.webhost.com',
		'account_id' => 'newaccount',
		'account_property' => 'webhostusa',
		'email' => 'newaccount@webhost.com',
		'company' => 'New Account Co.',
		'first_name' => 'John',
		'last_name' => 'Smith',
		'address_1' => '123 Some Street',
		'city' => 'Ocean City',
		'state' => 'New Jersey',
		'country' => 'USA',
		'postal' => '08226',
		'phone_2' => '555-123-4567'
	);
	if (!$result = $BT_Services->account_signup($params))
		$result = $BT_Services->last_fault();
	else
		$result = 'account_signup'.str_replace('Array', '', print_r($result, true));
	echo "<pre>{$result}</pre>";

	// check the status of the new signup...
	$params = array
	(
		'account_uuid' => 'b27e3d839a4242e2829d0c189ee41533'
	);
	if (!$result = $BT_Services->account_status($params))
		$result = $BT_Services->last_fault();
	else
		$result = 'account_status'.str_replace('Array', '', print_r($result, true));
	echo "<pre>{$result}</pre>";


?>
</body>
</html>
